#
# spec file for package neovim
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           neovim
Version:        0.1.4
Release:        1.18
Summary:        Vim-fork focused on extensibility and agility
License:        Apache-2.0
Group:          Productivity/Editors/Vi
Url:            https://neovim.io/
Source:         https://github.com/neovim/neovim/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        neovim.svg
Source2:        neovim.desktop
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libmsgpack-devel >= 1.2.0
BuildRequires:  libmsgpackc-devel >= 1.2.0
BuildRequires:  libuv-devel
BuildRequires:  lua51-BitOp
BuildRequires:  lua51-LPeg
BuildRequires:  lua51-mpack
BuildRequires:  luajit-devel
BuildRequires:  pkg-config
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(jemalloc)
BuildRequires:  pkgconfig(termkey)
BuildRequires:  pkgconfig(unibilium)
BuildRequires:  pkgconfig(vterm)
Recommends:     python-neovim
Recommends:     python3-neovim
Recommends:     xsel

%description
Neovim is a refactor - and sometimes redactor - in the tradition of Vim, which
itself derives from Stevie. It is not a rewrite, but a continuation and
extension of Vim. Many rewrites, clones, emulators and imitators exist; some are
very clever, but none are Vim. Neovim strives to be a superset of Vim,
notwithstanding some intentionally removed misfeatures; excepting those few and
carefully-considered excisions, Neovim is Vim. It is built for users who want
the good parts of Vim, without compromise, and more.

%prep
%setup -q

# Remove __DATE__ and __TIME__
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{_sourcedir}/%{name}.changes")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
TIME="\"$(date -d "${modified}" "+%%R")\""
find .  -name '*.[ch]' | xargs sed -i "s/__DATE__/${DATE}/g;s/__TIME__/${TIME}/g"

%build
%cmake -DLUA_PRG=%{_bindir}/lua \
       -DUSE_BUNDLED=OFF \
       -DLUAJIT_USE_BUNDLED=OFF \
       -DCMAKE_BUILD_TYPE=Release \
       -DCMAKE_INSTALL_PREFIX:PATH=%{_prefix} \
       -DENABLE_JEMALLOC=ON

make %{?_smp_mflags}

%install
pushd build
make %{?_smp_mflags} DESTDIR=%{buildroot} install
popd

# Install icon.
install -D -m 644 %{SOURCE1} %{buildroot}/%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

# Install desktop file.
install -D -m 644 %{SOURCE2} %{buildroot}/%{_datadir}/applications/%{name}.desktop

# Create hardlinks for duplicate files.
%fdupes %{buildroot}%{_datadir}/nvim/runtime/ftplugin/

%suse_update_desktop_file -r neovim ConsoleOnly Application Utility TextEditor

%find_lang nvim

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files -f nvim.lang
%defattr(-,root,root)
%doc BACKERS.md CONTRIBUTING.md LICENSE README.md
%{_bindir}/nvim
%{_datadir}/applications/%{name}.desktop
%{_datadir}/nvim/
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_mandir}/man1/nvim.1%{ext_man}

%changelog
* Thu Apr 28 2016 ronisbr@gmail.com
- Update to version 0.1.4.
- Run spec-cleaner in `neovim.spec`.
- Replace lua51-MessagePack build dependency to lua51-mpack.
- Changelog:
    Features:
  * 5ebffaa :tcd for tab-local working directory (like :lcd,
    but for tabs)
  * d835c03 remote/define.vim: support remote function "range"
  * 007d573 json_encode/json_decode (with sophisticated error
    detection) #4131
  * b50afb4 clipboard: support "lemonade" tool
    Fixes:
  * cc1beec eval.c: Fix heap corruption error. #4592
  * 4043725 mbyte.c: Fix invalid memory access in
    utfc_ptr2char_len #4574
  * 4eb5827 Enable syntax/filetype by default. #4558
    Changes:
  * 5c6592f v:windowid is writeable (useful for GUIs) #4608A
* Thu Apr 14 2016 ronisbr@gmail.com
- Change icon 'neovim.svg' installation directory from
    %%{_datadir}/pixmaps/%%{name}.svg
  to
    %%{_datadir}/icons/hicolor/scalable/apps/%%{name}.svg
  as per dimstar request.
- Fix neovim.changes indentation.
* Sat Apr  9 2016 ronisbr@gmail.com
- Remove unneeded patches that were applied by upstream:
  * neovim_fix_locale_dir_01.patch
  * neovim_fix_locale_dir_02.patch
- Update to version 0.1.3.
- Changelog:
    Features:
  * f2ae5a9 Add TextYankPost and TextDeletePost autocmds
  * 44b2cef bufhl: new mechanism for plugins to add highlights
    to a buffer
  * 39c3842 Make set{qf,loc}list() take {title}
  * 77a7ca4 'shortmess': Add "F" flag. #4446
  * 99d4c8c keymap: Support <D-...> (super/command key).
    Fixes:
  * 14c9b30 terminal.c: temporary fix for incorrect paste
    handling
    Notable changes:
  * 50e129f defaults: Enable syntax and filetype plugins.
  * 4e39eee upgrade libvterm (improves terminal reflow)
* Tue Mar  8 2016 ronisbr@gmail.com
- Backport two patches that fix translations in Neovim:
  * neovim_fix_locale_dir_01.patch
  * neovim_fix_locale_dir_02.patch
- Update to version 0.1.2.
- Changelog:
    Features:
  * ef66249 tabline: Add %%[] atom to the tabline, for random
    commands on click
  * f338ea7 job control: implement jobpid() to get PID of job
  * d0d5d17 job control: add 'detach' option to jobstart
  * 7ad3f07 Add support for binary numbers
    Fixes:
  * 291495a regexp_nfa.c: Speed up find_match_text()
  * 317d5ca input: Do not set high-bit; preserve ALT modifier.
  * 3b7c409 shell: Unquote &shell* options before using them
    Notable changes:
  * 49b06a8 encoding: Always use "utf-8" as default for
    &encoding
  * 79a6983 ui: revert "gui_running" hack
    Other changes:
  * b4b4536 version: semver.org compliance
  * c6aa716 reproducible builds: Stop using __{DATE,TIME}__
  * 46bd3c0 clipboard: Check $DISPLAY. Prefer xsel. #4150
  * f6ecd12 job control: don't kill PTY processes on exit
  * 49f0417 clipboard: Detach clipboard helper, so contents is
    kept after nvim exit
  * 38435e8 python: Add missing I/O methods to RedirectStream
  * d26b01d eval: Use better error messages when failing to
    dump values
  * 62d137c Remove swapsync.
* Fri Jan 22 2016 ronisbr@gmail.com
- Add neovim desktop file.
* Mon Jan 11 2016 ronisbr@gmail.com
- Add neovim logo to the package.
* Sat Dec  5 2015 ronisbr@gmail.com
- Update to version 0.1.1.
- Changelog:
  * shada/msgpack editor plugin #3270
  * VimL Dict notifications #3603
  * Note: API for this feature may change.
  * :profile dump, :profile stop #2427
  * :oldfiles! #3611
  * TermOpen, TermClose events #3653
  * fix: shada/viminfo: Do not save unlisted and quickfix buffers
    [#3581]
* Thu Dec  3 2015 ronisbr@gmail.com
- Remove xclip of recommended packages list.
* Thu Dec  3 2015 ronisbr@gmail.com
- Add python-neovim and python3-neovim as recommended packages.
* Wed Dec  2 2015 ronisbr@gmail.com
- Initial version based on home:darix:neovim/neovim
